import fnmatch
import time
import globsters
from globsters import Globsters

data = [
    "file.txt",
    "file.py",
    "file.exe",
    "file.PY",
]

iterations = 100_000


def fnmatch_bench():
    for i in range(iterations):
        for d in data:
            fnmatch.fnmatch(d, "*.py")


def globsters_bench():
    globster_matcher = globsters.globster("*.py", case_insensitive=True)
    for i in range(iterations):
        for d in data:
            globster_matcher(d)


def do_match():
    globster_matcher = globsters.globster("*.py", case_insensitive=True)
    for d in data:
        fn_res = fnmatch.fnmatch(d, "*.py")
        gl_res = globster_matcher(d)
        if fn_res != gl_res:
            print(f"fn_res: {fn_res}, gl_res: {gl_res} ~ '{d}'")
            assert fnmatch == globster_matcher


def main():
    do_match()
    ti_a = time.perf_counter()
    fnmatch_bench()
    tf_a = time.perf_counter()
    dt_a = tf_a - ti_a
    print(f"fnmatch_bench: {dt_a:.3f} seconds")

    ti_b = time.perf_counter()
    globsters_bench()
    tf_b = time.perf_counter()
    dt_b = tf_b - ti_b
    print(f"globsters_bench: {dt_b:.3f} seconds")


if __name__ == "__main__":
    main()



from __future__ import annotations
from typing import Sequence
from .globsters import *

__version__ = __version_lib__
__all__ = ("__version__",)


def globster(pattern: str, case_insensitive: bool = False):
    return globsters.Globster(pattern, case_insensitive)


# def glob(patterns: Sequence[str], case_insensitive: bool = True) -> Globsters:
#     """Create a globset from a sequence of glob patterns.

#     :param patterns: A sequence of glob patterns.
#     :param case_sensitive: Whether the glob patterns should be case sensitive.
#     :return: A :class:`PyGlobset` instance.
#     """
#     if isinstance(patterns, str):
#         raise TypeError("patterns must be a sequence of strings")
#     return Globsters(patterns, case_insensitive)

__doc__ = globsters.__doc__
if hasattr(globsters, "__all__"):
    __all__ = globsters.__all__



import globsters


def test_version():
    assert globsters.__version__ is not None


def test_single_globster():
    matcher = globsters.Globster("*.py")
    assert matcher.is_match("file.py")
    assert not matcher.is_match("file.txt")


def test_single_globster_callable():
    matcher = globsters.Globster("*.py")
    assert matcher("file.py")
    assert not matcher("file.txt")


def test_multiple_globsters():
    globset = globsters.Globsters(["*.py", "*.txt"])
    assert globset.is_match("file.py")
    assert globset.is_match("file.txt")
    assert not globset.is_match("file.exe")


def test_multiple_globsters_callable():
    globset = globsters.Globsters(["*.py", "*.txt"])
    assert globset("file.py")
    assert globset("file.txt")
    assert globset("path/to/a/file.txt")

    assert not globset("file.PY")
    assert not globset("file.TXT")
    assert not globset("file.TxT")
    assert not globset("file.exe")


def test_multiple_globsters_negative():
    globset = globsters.Globsters(["*.py", "!*.txt"])
    assert globset("file.py")
    assert globset("file.txt") is False
    assert not globset("path/to/a/file.txt")
    assert not globset("file.exe")


def test_multiple_globsters_case_insensitive():
    globset = globsters.Globsters(["*.py", "*.txt"], True)
    assert globset("file.py")
    assert globset("file.PY")
    assert globset("file.txt")
    assert globset("file.TXT")
    assert globset("file.TxT")
    assert not globset("file.exe")


def dev():
    print(dir(globsters))

    matcher = globsters.Globster("*.py")

    isfile = matcher.is_match("file.py")  # True
    assert isfile
    print(isfile)
    is_not_file = matcher.is_match("file.txt")  # False
    print(is_not_file)
    assert not is_not_file


if __name__ == "__main__":
    dev()
